# IntegrationScript

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**commands** | [**list[Command]**](Command.md) |  | [optional] 
**docker_image** | **str** |  | [optional] 
**feed** | **bool** |  | [optional] 
**is_fetch** | **bool** |  | [optional] 
**is_fetch_credentials** | **bool** |  | [optional] 
**long_running** | **bool** |  | [optional] 
**long_running_port_mapping** | **bool** |  | [optional] 
**run_once** | **bool** |  | [optional] 
**script** | **str** |  | [optional] 
**subtype** | [**ScriptSubType**](ScriptSubType.md) |  | [optional] 
**type** | [**ScriptType**](ScriptType.md) |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


